#include <napi.h>

#include "Extras/Utils/nutils.h"
#include "QtCore/QDate/qdate_wrap.h"
#include "QtCore/QDateTime/qdatetime_wrap.h"
#include "QtCore/QModelIndex/qmodelindex_wrap.h"
#include "QtCore/QObject/qobject_wrap.h"
#include "QtCore/QPoint/qpoint_wrap.h"
#include "QtCore/QRect/qrect_wrap.h"
#include "QtCore/QSettings/qsettings_wrap.h"
#include "QtCore/QSize/qsize_wrap.h"
#include "QtCore/QTime/qtime_wrap.h"
#include "QtCore/QUrl/qurl_wrap.h"
#include "QtCore/QVariant/qvariant_wrap.h"
#include "QtGui/QApplication/qapplication_wrap.h"
#include "QtGui/QBrush/qbrush_wrap.h"
#include "QtGui/QClipboard/qclipboard_wrap.h"
#include "QtGui/QColor/qcolor_wrap.h"
#include "QtGui/QCursor/qcursor_wrap.h"
#include "QtGui/QEvent/QKeyEvent/qkeyevent_wrap.h"
#include "QtGui/QEvent/QMouseEvent/qmouseevent_wrap.h"
#include "QtGui/QFont/qfont_wrap.h"
#include "QtGui/QFontDatabase/qfontdatabase_wrap.h"
#include "QtGui/QIcon/qicon_wrap.h"
#include "QtGui/QKeySequence/qkeysequence_wrap.h"
#include "QtGui/QMovie/qmovie_wrap.h"
#include "QtGui/QPicture/qpicture_wrap.h"
#include "QtGui/QPixmap/qpixmap_wrap.h"
#include "QtGui/QStyle/qstyle_wrap.h"
#include "QtWidgets/QAction/qaction_wrap.h"
#include "QtWidgets/QBoxLayout/qboxlayout_wrap.h"
#include "QtWidgets/QButtonGroup/qbuttongroup_wrap.h"
#include "QtWidgets/QCalendarWidget/qcalendarwidget_wrap.h"
#include "QtWidgets/QCheckBox/qcheckbox_wrap.h"
#include "QtWidgets/QColorDialog/qcolordialog_wrap.h"
#include "QtWidgets/QComboBox/qcombobox_wrap.h"
#include "QtWidgets/QDateEdit/qdateedit_wrap.h"
#include "QtWidgets/QDateTimeEdit/qdatetimeedit_wrap.h"
#include "QtWidgets/QDial/qdial_wrap.h"
#include "QtWidgets/QDialog/qdialog_wrap.h"
#include "QtWidgets/QDoubleSpinBox/qdoublespinbox_wrap.h"
#include "QtWidgets/QErrorMessage/qerrormessage_wrap.h"
#include "QtWidgets/QFileDialog/qfiledialog_wrap.h"
#include "QtWidgets/QFontDialog/qfontdialog_wrap.h"
#include "QtWidgets/QFrame/qframe_wrap.h"
#include "QtWidgets/QGridLayout/qgridlayout_wrap.h"
#include "QtWidgets/QGroupBox/qgroupbox_wrap.h"
#include "QtWidgets/QInputDialog/qinputdialog_wrap.h"
#include "QtWidgets/QLCDNumber/qlcdnumber_wrap.h"
#include "QtWidgets/QLabel/qlabel_wrap.h"
#include "QtWidgets/QLayout/qlayout_wrap.h"
#include "QtWidgets/QLineEdit/qlineedit_wrap.h"
#include "QtWidgets/QListView/qlistview_wrap.h"
#include "QtWidgets/QListWidget/qlistwidget_wrap.h"
#include "QtWidgets/QListWidgetItem/qlistwidgetitem_wrap.h"
#include "QtWidgets/QMainWindow/qmainwindow_wrap.h"
#include "QtWidgets/QMenu/qmenu_wrap.h"
#include "QtWidgets/QMenuBar/qmenubar_wrap.h"
#include "QtWidgets/QMessageBox/qmessagebox_wrap.h"
#include "QtWidgets/QPainter/qpainter_wrap.h"
#include "QtWidgets/QPlainTextEdit/qplaintextedit_wrap.h"
#include "QtWidgets/QProgressBar/qprogressbar_wrap.h"
#include "QtWidgets/QProgressDialog/qprogressdialog_wrap.h"
#include "QtWidgets/QPushButton/qpushbutton_wrap.h"
#include "QtWidgets/QRadioButton/qradiobutton_wrap.h"
#include "QtWidgets/QScrollArea/qscrollarea_wrap.h"
#include "QtWidgets/QScrollBar/qscrollbar_wrap.h"
#include "QtWidgets/QShortcut/qshortcut_wrap.h"
#include "QtWidgets/QSlider/qslider_wrap.h"
#include "QtWidgets/QSpinBox/qspinbox_wrap.h"
#include "QtWidgets/QStackedWidget/qstackedwidget_wrap.h"
#include "QtWidgets/QStandardItem/qstandarditem_wrap.h"
#include "QtWidgets/QStandardItemModel/qstandarditemmodel_wrap.h"
#include "QtWidgets/QStatusBar/qstatusbar_wrap.h"
#include "QtWidgets/QSystemTrayIcon/qsystemtrayicon_wrap.h"
#include "QtWidgets/QTabBar/qtabbar_wrap.h"
#include "QtWidgets/QTabWidget/qtabwidget_wrap.h"
#include "QtWidgets/QTableView/qtableview_wrap.h"
#include "QtWidgets/QTableWidget/qtablewidget_wrap.h"
#include "QtWidgets/QTableWidgetItem/qtablewidgetitem_wrap.h"
#include "QtWidgets/QTimeEdit/qtimeedit_wrap.h"
#include "QtWidgets/QToolButton/qtoolbutton_wrap.h"
#include "QtWidgets/QTreeWidget/qtreewidget_wrap.h"
#include "QtWidgets/QTreeWidgetItem/qtreewidgetitem_wrap.h"
#include "QtWidgets/QWidget/qwidget_wrap.h"
#include "core/FlexLayout/flexlayout_wrap.h"
#include "core/Integration/integration.h"
// These cant be instantiated in JS Side
void InitPrivateHelpers(Napi::Env env) {
  qodeIntegration::integrate();
  QLayoutWrap::init(env);  // Abstact class wrapper for pointing to any layout
}

Napi::Object Main(Napi::Env env, Napi::Object exports) {
  InitPrivateHelpers(env);
  NUtilsWrap::init(env, exports);
  QApplicationWrap::init(env, exports);
  QDateWrap::init(env, exports);
  QDateTimeWrap::init(env, exports);
  QModelIndexWrap::init(env, exports);
  QObjectWrap::init(env, exports);
  QPointWrap::init(env, exports);
  QRectWrap::init(env, exports);
  QSizeWrap::init(env, exports);
  QTimeWrap::init(env, exports);
  QUrlWrap::init(env, exports);
  QVariantWrap::init(env, exports);
  QBrushWrap::init(env, exports);
  QColorWrap::init(env, exports);
  QClipboardWrap::init(env, exports);
  QDialogWrap::init(env, exports);
  QWidgetWrap::init(env, exports);
  QPictureWrap::init(env, exports);
  QPixmapWrap::init(env, exports);
  QKeySequenceWrap::init(env, exports);
  QFontDatabaseWrap::init(env, exports);
  QIconWrap::init(env, exports);
  QFontWrap::init(env, exports);
  QMovieWrap::init(env, exports);
  QStyleWrap::init(env, exports);
  QCursorWrap::init(env, exports);
  QCalendarWidgetWrap::init(env, exports);
  QColorDialogWrap::init(env, exports);
  QComboBoxWrap::init(env, exports);
  QDoubleSpinBoxWrap::init(env, exports);
  QBoxLayoutWrap::init(env, exports);
  QDateEditWrap::init(env, exports);
  QDateTimeEditWrap::init(env, exports);
  QErrorMessageWrap::init(env, exports);
  QFileDialogWrap::init(env, exports);
  QFontDialogWrap::init(env, exports);
  QFrameWrap::init(env, exports);
  QListViewWrap::init(env, exports);
  QListWidgetWrap::init(env, exports);
  QListWidgetItemWrap::init(env, exports);
  QTableViewWrap::init(env, exports);
  QTableWidgetWrap::init(env, exports);
  QTableWidgetItemWrap::init(env, exports);
  QPainterWrap::init(env, exports);
  QTreeWidgetWrap::init(env, exports);
  QTreeWidgetItemWrap::init(env, exports);
  QGridLayoutWrap::init(env, exports);
  QGroupBoxWrap::init(env, exports);
  FlexLayoutWrap::init(env, exports);
  QMainWindowWrap::init(env, exports);
  QPushButtonWrap::init(env, exports);
  QToolButtonWrap::init(env, exports);
  QSpinBoxWrap::init(env, exports);
  QCheckBoxWrap::init(env, exports);
  QProgressBarWrap::init(env, exports);
  QProgressDialogWrap::init(env, exports);
  QRadioButtonWrap::init(env, exports);
  QStackedWidgetWrap::init(env, exports);
  QTabBarWrap::init(env, exports);
  QTabWidgetWrap::init(env, exports);
  QLineEditWrap::init(env, exports);
  QKeyEventWrap::init(env, exports);
  QMouseEventWrap::init(env, exports);
  QPlainTextEditWrap::init(env, exports);
  QDialWrap::init(env, exports);
  QLabelWrap::init(env, exports);
  QLCDNumberWrap::init(env, exports);
  QScrollAreaWrap::init(env, exports);
  QScrollBarWrap::init(env, exports);
  QSystemTrayIconWrap::init(env, exports);
  QActionWrap::init(env, exports);
  QShortcutWrap::init(env, exports);
  QMenuWrap::init(env, exports);
  QMenuBarWrap::init(env, exports);
  QMessageBoxWrap::init(env, exports);
  QInputDialogWrap::init(env, exports);
  QSliderWrap::init(env, exports);
  QTimeEditWrap::init(env, exports);
  QButtonGroupWrap::init(env, exports);
  QStatusBarWrap::init(env, exports);
  QSettingsWrap::init(env, exports);
  QStandardItemModelWrap::init(env, exports);
  QStandardItemWrap::init(env, exports);
  return exports;
}

NODE_API_MODULE(NODE_GYP_MODULE_NAME, Main)